@@ -18,7 +18,7 @@
    You should have received a copy of the GNU General Public License along
    with LuaTeX; if not, see <http://www.gnu.org/licenses/>. */
 
-/* $Id: ptexlib.h 3510 2010-03-16 16:34:26Z taco $ */
+/* $Id: ptexlib.h 3636 2010-04-20 13:31:45Z taco $ */
 
 #ifndef PTEXLIB_H
 #  define PTEXLIB_H
@@ -27,13 +27,14 @@
 #  define EXTERN extern
 #  include "luatex.h"
 
+#   include "lib/lib.h"
+
 #  ifdef MSVC
 extern double rint(double x);
 #  endif
 
-extern string fullnameoffile;
 #  if defined(WIN32) || defined(__MINGW32__) || defined(__CYGWIN__)
-extern char **suffixlist;
+extern char **suffixlist; /* in luainit.w */
 #  endif
 
 
@@ -406,7 +407,7 @@ extern void topenin(void);
 /* extern void calledit (); */
 
 /* Set an array size from texmf.cnf.  */
-extern void setupboundvariable(integer *, const_string, integer);
+/*extern void setupboundvariable(integer *, const_string, integer);*/
 
 /* here  are a few functions that used to be in coerce.h */
 
